Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1408)

Unified Diff: content/public/common/content_features.cc

Issue 2450833003: Separate rAF aligned Touch and Mouse Input settings (Closed)
Patch Set: Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/common/content_features.cc
diff --git a/content/public/common/content_features.cc b/content/public/common/content_features.cc
index bcb2caa47041a95eed4d71155218f38bddbb52a2..74bb621c94bc0217ec1b4203097e840c13fac5dd 100644
--- a/content/public/common/content_features.cc
+++ b/content/public/common/content_features.cc
@@ -140,9 +140,13 @@ const base::Feature kPointerEvents{"PointerEvent",
const base::Feature kPointerEventV1SpecCapturing{
"PointerEventV1SpecCapturing", base::FEATURE_DISABLED_BY_DEFAULT};
-// RAF aligned input events support.
-const base::Feature kRafAlignedInputEvents{"RafAlignedInput",
- base::FEATURE_DISABLED_BY_DEFAULT};
+// RAF aligned touch input events support.
+const base::Feature kRafAlignedTouchInputEvents{
rkaplow 2016/10/25 20:05:51 should be alphabetized
dtapuska 2016/10/26 02:34:52 Done.
+ "RafAlignedTouchInput", base::FEATURE_DISABLED_BY_DEFAULT};
+
+// RAF aligned mouse input events support.
+const base::Feature kRafAlignedMouseInputEvents{
+ "RafAlignedMouseInput", base::FEATURE_DISABLED_BY_DEFAULT};
// If Pepper 3D Image Chromium is allowed, this feature controls whether it is
// enabled.

Powered by Google App Engine
This is Rietveld 408576698